@@ -64,6 +64,7 @@ setClass("flow", representation(jobs = "list",
 																status = "character", ## status
 																mode = "character", ## what kind of flow this is
 																name = "character",
+																module_cmds = "character",
 																version = "character",
 																execute = "logical"))
 
@@ -111,8 +112,7 @@ setClass("flow", representation(jobs = "list",
 #' 
 #' @keywords queue
 #' 
-#' @export
-#' 
+#' @export 
 #' @examples
 #' qobj <- queue(platform='lsf')
 queue <- function(object,
@@ -333,6 +333,8 @@ job <- function(cmds = "",
 #' @param status \code{character}: Status of the flow.
 #' @param version version of flowr used to create and execute this flow.
 #' @param execute executtion status of flow object. [FALSE]
+#' @param module_cmds [advanced use] a character vector of cmds which will be pre-pended to all script of this pipeline. 
+#' Could be cmds like \code{`module load mytool1;module load mytool2`}
 #' @export
 #' @examples
 #' cmds = rep("sleep 5", 10)
@@ -366,11 +368,12 @@ flow <- function(
 	name = "newflow",
 	desc = "my_super_flow",
 	mode = c("scheduler","trigger","R"),
-	flow_run_path = get_opts("flow_run_path"),
+	flow_run_path = opts_flow$get("flow_run_path"),
 	trigger_path = "",
 	flow_path = "",
 	version = '0.0',
 	status="created",
+	module_cmds = opts_flow$get("module_cmds"),
 	execute = ""){
 	mode <- match.arg(mode)
 	## create a list of jobs if nore already
@@ -382,6 +385,7 @@ flow <- function(
 								name = name, flow_run_path = flow_run_path,
 								trigger_path = trigger_path,
 								flow_path=flow_path,
+								module_cmds = module_cmds,
 								desc=desc,
 								version = version,
 								status=status)
